__title__ = 'mixcoatl'
__version__ = '0.2.7'
__author__ = 'John E. Vincent'
__license__ = 'Apache 2.0'
__copyright__ = 'Copyright 2012-2013 John E. Vincent, enStratus Networks Inc'
